.. image:: https://github.com/pulp/pulp_cookbook/actions/workflows/nightly.yml/badge.svg
   :target: https://github.com/pulp/pulp_cookbook/actions/workflows/nightly.yml
   :alt: Cookbook Nightly CI/CD
.. image:: https://img.shields.io/pypi/v/pulp-cookbook.svg
   :target: https://pypi.python.org/pypi/pulp-cookbook
   :alt: PyPI
.. image:: https://img.shields.io/pypi/pyversions/pulp-cookbook.svg
   :target: https://pypi.python.org/pypi/pulp-cookbook
   :alt: PyPI - Python Version
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Code style: black


pulp-cookbook Plugin
====================

The ``cookbook`` plugin extends `pulpcore
<https://pypi.python.org/pypi/pulpcore/>`_ to support hosting Chef cookbooks.
This plugin assumes some familiarity with the `pulpcore documentation
<https://docs.pulpproject.org/en/3.0/nightly/>`_.

For more information, please see the `documentation <https://pulp-cookbook.readthedocs.io/>`_
or the `Pulp project page <https://pulpproject.org>`_.
